==> haskell-generic-deriving-1.12.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-generic-deriving.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-deriving
version: 1.12.2
id: generic-deriving-1.12.2-DYcFACc3Ut7LhVuqzdHANA
key: generic-deriving-1.12.2-DYcFACc3Ut7LhVuqzdHANA
license: BSD-3-Clause
copyright: 2011-2013 Universiteit Utrecht, University of Oxford
maintainer: generics@haskell.org
author: José Pedro Magalhães
stability: experimental
homepage: https://github.com/dreixel/generic-deriving
synopsis: Generic programming library for generalised deriving.
description:
    This package provides functionality for generalising the deriving mechanism
    in Haskell to arbitrary classes. It was first described in the paper:
    .
    *  /A generic deriving mechanism for Haskell/.
    Jose Pedro Magalhaes, Atze Dijkstra, Johan Jeuring, and Andres Loeh.
    Haskell'\''10.
    .
    The current implementation integrates with the new GHC Generics. See
    <http://www.haskell.org/haskellwiki/GHC.Generics> for more information.
    Template Haskell code is provided for supporting older GHCs.
category: Generics
abi: 6b93df2b4d12e084434471edc180d2d5
exposed: True
exposed-modules:
    Generics.Deriving Generics.Deriving.Base Generics.Deriving.ConNames
    Generics.Deriving.Copoint Generics.Deriving.Enum
    Generics.Deriving.Eq Generics.Deriving.Foldable
    Generics.Deriving.Functor Generics.Deriving.Instances
    Generics.Deriving.Monoid Generics.Deriving.Semigroup
    Generics.Deriving.Show Generics.Deriving.TH
    Generics.Deriving.Traversable Generics.Deriving.Uniplate
hidden-modules: Generics.Deriving.Base.Internal
                Generics.Deriving.TH.Internal Paths_generic_deriving
                Generics.Deriving.TH.Post4_9
import-dirs: /usr/lib/ghc-8.4.3/site-local/generic-deriving-1.12.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/generic-deriving-1.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/generic-deriving-1.12.2
hs-libraries: HSgeneric-deriving-1.12.2-DYcFACc3Ut7LhVuqzdHANA
depends:
    containers-0.5.11.0 ghc-prim-0.5.2.0 template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 base-4.11.1.0
abi-depends: containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=4938497122b3b44bd39134a6de0cb043
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-generic-deriving/html/generic-deriving.haddock
haddock-html: /usr/share/doc/haskell-generic-deriving/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-deriving-1.12.2-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-generic-deriving.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-deriving
version: 1.12.2
id: generic-deriving-1.12.2-8hn6yJgFzQpFsROKKgqJi6
key: generic-deriving-1.12.2-8hn6yJgFzQpFsROKKgqJi6
license: BSD-3-Clause
copyright: 2011-2013 Universiteit Utrecht, University of Oxford
maintainer: generics@haskell.org
author: José Pedro Magalhães
stability: experimental
homepage: https://github.com/dreixel/generic-deriving
synopsis: Generic programming library for generalised deriving.
description:
    This package provides functionality for generalising the deriving mechanism
    in Haskell to arbitrary classes. It was first described in the paper:
    .
    *  /A generic deriving mechanism for Haskell/.
    Jose Pedro Magalhaes, Atze Dijkstra, Johan Jeuring, and Andres Loeh.
    Haskell'\''10.
    .
    The current implementation integrates with the new GHC Generics. See
    <http://www.haskell.org/haskellwiki/GHC.Generics> for more information.
    Template Haskell code is provided for supporting older GHCs.
category: Generics
abi: a889c2cf6ca552c81055fde29c3fe1fd
exposed: True
exposed-modules:
    Generics.Deriving Generics.Deriving.Base Generics.Deriving.ConNames
    Generics.Deriving.Copoint Generics.Deriving.Enum
    Generics.Deriving.Eq Generics.Deriving.Foldable
    Generics.Deriving.Functor Generics.Deriving.Instances
    Generics.Deriving.Monoid Generics.Deriving.Semigroup
    Generics.Deriving.Show Generics.Deriving.TH
    Generics.Deriving.Traversable Generics.Deriving.Uniplate
hidden-modules: Generics.Deriving.Base.Internal
                Generics.Deriving.TH.Internal Paths_generic_deriving
                Generics.Deriving.TH.Post4_9
import-dirs: /usr/lib/ghc-8.4.3/site-local/generic-deriving-1.12.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/generic-deriving-1.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/generic-deriving-1.12.2
hs-libraries: HSgeneric-deriving-1.12.2-8hn6yJgFzQpFsROKKgqJi6
depends:
    containers-0.5.11.0 ghc-prim-0.5.2.0 template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 base-4.11.1.0
abi-depends: containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=4938497122b3b44bd39134a6de0cb043
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-generic-deriving/html/generic-deriving.haddock
haddock-html: /usr/share/doc/haskell-generic-deriving/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
